#
# spec file for package xsp
#
# Copyright (c) 2020 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define xspConfigsLocation %{_sysconfdir}/xsp/2.0
%define xspAvailableApps %{xspConfigsLocation}/applications-available
%define xspEnabledApps %{xspConfigsLocation}/applications-enabled
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           xsp
Version:        4.7.1
Release:        2.3
Summary:        Web Server Hosting ASP.NET
License:        MIT
Group:          Productivity/Networking/Web/Servers
URL:            https://github.com/mono/xsp
Source:         https://github.com/mono/xsp/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        xsp.conf
Patch1:         %{name}-3.0.11-fix-bashisms.patch
Patch2:         mono-440-build-fix.patch
Patch3:         mono-4-install.patch
Patch4:         xsp-add-systemd-support.patch
Patch5:         asp-state4-signals.patch
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  mono-data-oracle
BuildRequires:  mono-data-sqlite
BuildRequires:  mono-devel >= 2.10.0
BuildRequires:  mono-web
BuildRequires:  monodoc-core
BuildRequires:  pkgconfig
BuildRequires:  sqlite-devel
BuildRequires:  systemd-rpm-macros
Requires:       libfpm_helper0 = %{version}
%{?systemd_ordering}
%if 0%{?suse_version} >= 1330
BuildRequires:  strip-nondeterminism
Requires(post): group(www)
Requires(post): user(wwwrun)
Requires(pre):  group(www)
Requires(pre):  user(wwwrun)
%endif

%description
The XSP server is a Web server that hosts the Mono System.Web
classes for running what is commonly known as ASP.NET.

%package -n libfpm_helper0
Summary:        Mono.WebServer.FPM Helper
Group:          System/Libraries

%description -n libfpm_helper0
Library of Mono.WebServer.FPM Helper.

%package -n libfpm_helper-devel
Summary:        Development files of libfpm_helper0
Group:          Development/Libraries/C and C++
Requires:       libfpm_helper0 = %{version}

%description -n libfpm_helper-devel
Development Files of libfpm_helper0.

%define mcsver %({ mcs --version | awk '{print $5}' | cut -f1 -d"." ; mcs --version | awk '{print $5}' | cut -f2 -d"." ; } | xargs printf "%03d")
%if 0%{?mcsver} >= 4000
%define target2_dir xsp2
%define target4_dir xsp4
%else
%define target2_dir 2.0
%define target4_dir 4.5
%endif

%prep
%setup -q
%patch -P 1 -p1
%if 0%{?mcsver} >= 4004
%patch -P 2 -p1
%endif
%if 0%{?mcsver} >= 4000
%patch -P 3 -p1
%endif
%patch -P 4 -p1
%patch -P 5 -p1

%build
NOCONFIGURE=1 ./autogen.sh
# Cannot use the configure macro because noarch-redhat-linux is not recognized by the auto tools in the tarball
./configure --prefix=%{_prefix} \
	    --libexecdir=%{_prefix}/lib \
	    --libdir=%{_prefix}/lib \
	    --mandir=%{_mandir} \
	    --infodir=%{_infodir} \
	    --sysconfdir=%{_sysconfdir}
%make_build

%install
[ -x %{_bindir}/strip-nondeterminism ] && strip-nondeterminism docs/Mono.FastCGI/Mono.FastCGI.zip docs/Mono.WebServer/Mono.WebServer.zip
%make_install
find %{buildroot}%{_prefix}/lib -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_prefix}/lib/xsp/unittests
mkdir -p %{buildroot}%{_datadir}
mv %{buildroot}%{_prefix}/lib/pkgconfig %{buildroot}%{_datadir}
mkdir -p %{buildroot}/%{xspAvailableApps}
mkdir -p %{buildroot}/%{xspEnabledApps}
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
mkdir -p %{buildroot}/srv/xsp2
mkdir -p %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}/run/xsp2
mkdir -p %{buildroot}%{_prefix}/lib/tmpfiles.d/
mkdir -p %{buildroot}%{_sbindir}
install -m 644 man/mono-asp-apps.1 %{buildroot}%{_mandir}/man1/mono-asp-apps.1
install -m 644 packaging/opensuse/sysconfig.xsp2 %{buildroot}%{_fillupdir}
install -m 644 packaging/opensuse/xsp2.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/xsp2
# new {
mkdir -p %{buildroot}%{_datadir}/%{name}/scripts
install -m 755 packaging/opensuse/xsp2.init %{buildroot}%{_datadir}/%{name}/scripts
mkdir -p %{buildroot}%{_unitdir}
install -m 644 packaging/opensuse/xsp2.service %{buildroot}%{_unitdir}/xsp2.service
# } end new
install -m 755 tools/mono-asp-apps/mono-asp-apps %{buildroot}%{_bindir}/mono-asp-apps
install -m 644 %{SOURCE1} %{buildroot}%{_prefix}/lib/tmpfiles.d/
ln -s service %{buildroot}%{_sbindir}/rcxsp2
%fdupes %{buildroot}/%{_prefix}

%pre
%service_add_pre xsp2.service

%post
install -d -m 0711 --owner=wwwrun --group=www /run/xsp2
%service_add_post xsp2.service

%preun
%service_del_preun xsp2.service

%postun
%service_del_postun xsp2.service

%post -n libfpm_helper0 -p /sbin/ldconfig
%postun -n libfpm_helper0 -p /sbin/ldconfig

%files -n libfpm_helper0
%{_prefix}/lib/libfpm_helper.so.0.0.0

%files -n libfpm_helper-devel
%{_prefix}/lib/libfpm_helper.so
%{_prefix}/lib/libfpm_helper.so.0

%files
%doc NEWS README
%{_bindir}/*
%{_datadir}/pkgconfig/*
%dir %{_prefix}/lib/mono/%{target4_dir}
%{_prefix}/lib/mono/%{target4_dir}/Mono.WebServer2.dll
%{_prefix}/lib/mono/%{target4_dir}/fastcgi-mono-server4.exe
%{_prefix}/lib/mono/%{target4_dir}/mod-mono-server4.exe
%{_prefix}/lib/mono/%{target4_dir}/xsp4.exe
%{_prefix}/lib/mono/%{target4_dir}/mono-fpm.exe
%{_prefix}/lib/mono/gac/Mono.WebServer2
%{_prefix}/lib/mono/gac/fastcgi-mono-server4
%{_prefix}/lib/mono/gac/mod-mono-server4
%{_prefix}/lib/mono/gac/xsp4
%{_prefix}/lib/mono/gac/mono-fpm
%{_prefix}/lib/monodoc/sources/Mono.WebServer.*
%{_prefix}/lib/monodoc/sources/Mono.FastCGI.*
%{_prefix}/lib/xsp
%{_mandir}/*/*
# new {
%{_datadir}/%{name}
%{_unitdir}/xsp2.service
# } end new
%config %{_sysconfdir}/logrotate.d/xsp2
%{_fillupdir}/*
%attr(0711,wwwrun,www) /srv/xsp2
%ghost %attr(0711,wwwrun,www) /run/xsp2
%{_prefix}/lib/tmpfiles.d/
%{_sysconfdir}/%{name}
%{_sbindir}/rcxsp2

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Mar  2 2020 Marguerite Su <i@marguerite.su>
- update version 4.7.1
  * drop .NET 2.0 support
  * add Mono.WebServer.Fpm
* Mon Sep 23 2019 Thorsten Kukuk <kukuk@suse.com>
- removal of SuSEfirewall2 files, since SuSEfirewall2 has been
  replaced by firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Sun May 12 2019 Martin Liška <mliska@suse.cz>
- Add asp-state4-signals.patch in order to fix
  https://bugzilla.xamarin.com/show_bug.cgi?id=7838.
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Replace URL by new one (follow the http(s) redirects)
- Add systemd-rpm-macros and %%systemd_ordering
  to satisfy %%service_*.
- Use %%make_install, and limit fdupes to the btrfs subvolume.
- Ensure neutrality of descriptions.
* Fri Feb 15 2019 josef.moellers@suse.com
- Add systemd support.
  [bsc#1116055, xsp-add-systemd-support.patch]
* Sat Nov 17 2018 Markus Beth <markus.beth@web.de>
- fix factory build, use correct dependency for sqlite
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Sep 29 2017 jengelh@inai.de
- Add missing dependencies for %%post.
* Wed Aug  2 2017 i@marguerite.su
- fix factory build, add missing wwwrun user.
* Mon Apr 24 2017 bwiedemann@suse.com
- fix to correct version
  because only factory has strip-nondeterminism atm
  (and 42.3 which we ignore here)
* Fri Apr 21 2017 bwiedemann@suse.com
- use strip-nondeterminism to make build fully reproducible
* Sun Mar 19 2017 fwdsbs.to.11df@xoxy.net
- Add %%insserv_prereq %%fillup_prereq requires:
  * Fix build for factory and tumbleweed
* Sun Jun  5 2016 fwdsbs.to.11df@xoxy.net
- Added patch mono-440-build-fix.patch:
  * Alter mono libraries search path in order to fix build with mono 4.4.0 and up
- Added mono-4-install.patch:
  * Alter xsp mono package path for mono 4.0 and up in order to fix xsp2 startup crash
* Sun May 10 2015 Led <ledest@gmail.com>
- fix bashism in init script
- add patches:
  * xsp-3.0.11-fix-bashisms.patch
* Fri Jan 16 2015 p.drouand@gmail.com
- Update to version 3.11
  + Changelog/NEWS files have not been updated
- Use download Url as source
- Add autoconf and automake; required because of autogen script
- Minimal required version of mono is 2.10.0; fix mono dependency
  version
- Remove redundant %%clean section
- Remove obsolete conditional macros
- Use autogen script instead of autoreconf
* Fri Aug  1 2014 sfalken@opensuse.org
- Changed /var/run to /run in package, to fix rpmlint check failures in
  oS:Factory
- Modified:
    xsp.spec
    xsp.conf
* Thu Aug 11 2011 aj@suse.de
- Run fdupes
- Mark /var/run/xsp2 as %%ghost and create it during package install
- Add xsp.conf to create directory in /var/run
* Wed Apr 27 2011 ajorgensen@novell.com
- Update to 2.10.2
  * http://www.go-mono.com/archive/2.10.2
* Tue Feb 22 2011 ajorgensen@novell.com
- Update to 2.10
  * http://www.go-mono.com/archive/2.10
* Fri Jan  7 2011 ajorgensen@novell.com
- Update to 2.8.2
  * Fix for CVE-2010-4225, bnc#660070
  * http://www.go-mono.com/archive/2.8.2
* Tue Oct 12 2010 ajorgensen@novell.com
- Update to 2.8
  * http://www.go-mono.com/archive/2.8
* Tue Apr 27 2010 ajorgensen@novell.com
- Update to 2.6.4
  * http://www.mono-project.com/Release_Notes_Mono_2.6.4
* Tue Mar 16 2010 ajorgensen@novell.com
- Update to 2.6.3
  * http://www.mono-project.com/Release_Notes_Mono_2.6.3
* Tue Jan 26 2010 ajorgensen@novell.com
- Update to 2.6
  * http://www.mono-project.com/Release_Notes_Mono_2.6
* Tue Aug 11 2009 ajorgensen@novell.com
- Update to 2.4.2
  * http://www.mono-project.com/Release_Notes_Mono_2.4.2
* Tue Mar 31 2009 ajorgensen@novell.com
- Update to 2.4
  * http://www.mono-project.com/Release_Notes_Mono_2.4
* Wed Oct  1 2008 ajorgensen@novell.com
- Update to 2.0 RC4
  * Fixes bnc#431121
* Mon Sep 22 2008 ajorgensen@novell.com
- Update to 2.0 RC3
  * Defaults to 2.0 profile (fixes a bug in mod_mono)
* Tue Aug 26 2008 ajorgensen@novell.com
- Update to 2.0
  * Fixes bnc#350779, bnc#359783, bnc#363404, bnc#372220,
    bnc#324204, bnc#408723
  * Sync with mod_mono changes
* Tue Apr 22 2008 wberrier@suse.de
- update to 1.9.1 (bugfix release)
  - Output date header (instead of asp.net doing it)
* Tue Mar 25 2008 wberrier@suse.de
- update to 1.9
  - minor test updates
  - BaseRequestBroker fix: Check if the request ID is valid inside
  the lock.
* Mon Jan 14 2008 wberrier@suse.de
- update to 1.2.6
  - FastCGI support
* Fri Aug 31 2007 wberrier@suse.de
- xsp_1.2.5_p5_final.patch: Fix for regression in the request
  broker
* Fri Aug 17 2007 wberrier@suse.de
- xsp_1.2.5_p4.patch.bz2: Bugfixes found in 1.2.5
  - bugs: 81699, 81906, 82379, 82057
  - fixes ability to handle large (GB) uploads (needed for iFolder)
* Fri Aug  3 2007 wberrier@suse.de
- Update to 1.2.5
  - More robust exception handling
  - Fixed permissions bits for non executable scripts
  - virtual host support
  - New Documentation for Mono.WebServer
  - Improved event handling
* Wed Jun  6 2007 wberrier@novell.com
- Remove unnecessary path defines (prefix, sysconfdir)
- Update to 1.2.4
  - fix some race conditions and crashes
  - add tracing support
* Fri Apr 13 2007 wberrier@novell.com
- add %%debug_package so debug packages get created
* Wed Apr 11 2007 wberrier@novell.com
- Add mono dep/req for older distros
* Fri Mar  2 2007 wberrier@suse.de
- Update Update to 1.2.3
  - Bug fix #80230 (prevents possible nullref)
  - Support for response header encoding
* Tue Jan 23 2007 ro@suse.de
- drop requires for gnome-filesystem
* Sat Dec  2 2006 wberrier@suse.de
- Update to 1.2.1 (Fate #301111)
  - Bugfixes:
  - close the connection if there's an error reading the headers
  (including assembly loading exceptions due to a bad installation).
  - kill the warning that everyone is worried about.
* Sat Oct 21 2006 wberrier@suse.de
- Update to 1.1.18
  - 2.0 updates
* Thu Oct 19 2006 wberrier@suse.de
- Add mono-devel to fix bnc #213576 (missing provides)
* Tue Sep  5 2006 wberrier@suse.de
- Update to 1.1.17.1 bugfix release
- Read from the stream, not the socket as the socket data is
  encrypted when using SSL.
* Wed Aug 30 2006 wberrier@suse.de
- Update to 1.1.17
  - Added support for X.509 client certificates
  - Update to handle newly created AppDomains
* Tue Aug  1 2006 wberrier@suse.de
- update to 1.1.16.1
- better connection handling
- fixes bugs: 77698,78034,78621
* Wed Apr 26 2006 wberrier@suse.de
- Security update (remove all the duplicated slashes
  and don't do an extra Replace on non-windows.) and minor fix for
  [#78034].
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 wberrier@suse.de
- Update to 1.1.13, clean up deps
* Fri Nov 11 2005 wberrier@suse.de
- Update to 1.1.10, set libdir to lib/
* Fri Oct  7 2005 wberrier@suse.de
- Update to 1.1.9.2 and cleanup (I Don't think noarch mono needs
  libexec, so I disabled the patch)
* Tue Jul 19 2005 sbrabec@suse.cz
- Build as noarch (#81109).
* Fri Jul 15 2005 sbrabec@suse.cz
- Updated to version 1.0.9 (#96776).
* Mon Feb 21 2005 clahey@suse.de
- Updated to 1.0.6.
* Mon Feb  7 2005 ro@suse.de
- use /usr/lib/mono
* Tue Dec 14 2004 clahey@suse.de
- New package.
